"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAppInstance = void 0;
const api_1 = require("./api");
const instance_1 = require("./instance");
/**
 * Gets a new instantiated Piral instance using the provided options.
 * Very useful for server-side rendering.
 * @param config The configuration for creating the Piral instance.
 * @param options The options to use when rendering the Piral instance.
 * @deprecated Use `createInstance` directly.
 * @example
```ts
import { render } from 'react-dom';
import { getAppInstance } from 'piral';

const { app } = getAppInstance();
render(app, document.querySelector('#app'));
```
 */
function getAppInstance(config = {}, options = {}) {
    const { settings, layout, errors, dashboardPath, piralChildren } = options;
    const instance = (0, api_1.createPiral)(config, settings);
    const app = (0, instance_1.createInstanceElement)(instance, layout, errors, dashboardPath, piralChildren);
    return { instance, app };
}
exports.getAppInstance = getAppInstance;
//# sourceMappingURL=app.js.map